#[non_exhaustive]
#[repr(u32)]
pub enum Shape {
Show 36 variants Default = 1, ContextMenu = 2, Help = 3, Pointer = 4, Progress = 5, Wait = 6, Cell = 7, Crosshair = 8, Text = 9, VerticalText = 10, Alias = 11, Copy = 12, Move = 13, NoDrop = 14, NotAllowed = 15, Grab = 16, Grabbing = 17, EResize = 18, NResize = 19, NeResize = 20, NwResize = 21, SResize = 22, SeResize = 23, SwResize = 24, WResize = 25, EwResize = 26, NsResize = 27, NeswResize = 28, NwseResize = 29, ColResize = 30, RowResize = 31, AllScroll = 32, ZoomIn = 33, ZoomOut = 34, DndAsk = 35, AllResize = 36,
}
Available on crate feature wayland and Linux only.
cursor shapes

This enum describes cursor shapes.

The names are taken from the CSS W3C specification: https://w3c.github.io/csswg-drafts/css-ui/#cursor with a few additions.

Note that there are some groups of cursor shapes that are related: The first group is drag-and-drop cursors which are used to indicate the selected action during dnd operations. The second group is resize cursors which are used to indicate resizing and moving possibilities on window borders. It is recommended that the shapes in these groups should use visually compatible images and metaphors.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Default = 1

default cursor



ContextMenu = 2

a context menu is available for the object under the cursor



Help = 3

help is available for the object under the cursor



Pointer = 4

pointer that indicates a link or another interactive element



Progress = 5

progress indicator



Wait = 6

program is busy, user should wait



Cell = 7

a cell or set of cells may be selected



Crosshair = 8

simple crosshair



Text = 9

text may be selected



VerticalText = 10

vertical text may be selected



Alias = 11

drag-and-drop: alias of/shortcut to something is to be created



Copy = 12

drag-and-drop: something is to be copied



Move = 13

drag-and-drop: something is to be moved



NoDrop = 14

drag-and-drop: the dragged item cannot be dropped at the current cursor location



NotAllowed = 15

drag-and-drop: the requested action will not be carried out



Grab = 16

drag-and-drop: something can be grabbed



Grabbing = 17

drag-and-drop: something is being grabbed



EResize = 18

resizing: the east border is to be moved



NResize = 19

resizing: the north border is to be moved



NeResize = 20

resizing: the north-east corner is to be moved



NwResize = 21

resizing: the north-west corner is to be moved



SResize = 22

resizing: the south border is to be moved



SeResize = 23

resizing: the south-east corner is to be moved



SwResize = 24

resizing: the south-west corner is to be moved



WResize = 25

resizing: the west border is to be moved



EwResize = 26

resizing: the east and west borders are to be moved



NsResize = 27

resizing: the north and south borders are to be moved



NeswResize = 28

resizing: the north-east and south-west corners are to be moved



NwseResize = 29

resizing: the north-west and south-east corners are to be moved



ColResize = 30

resizing: that the item/column can be resized horizontally



RowResize = 31

resizing: that the item/row can be resized vertically



AllScroll = 32

something can be scrolled in any direction



ZoomIn = 33

something can be zoomed in



ZoomOut = 34

something can be zoomed out



DndAsk = 35

drag-and-drop: the user will select which action will be carried out (non-css value)



AllResize = 36

resizing: something can be moved or resized in any direction (non-css value)