Struct WpCursorShapeDeviceV1
pub struct WpCursorShapeDeviceV1 { /* private fields */ }wayland and Linux only.Expand description
cursor shape for a device
This interface allows clients to set the cursor shape.
This interface has no events.
Implementations
impl WpCursorShapeDeviceV1
impl WpCursorShapeDeviceV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the cursor shape device
Destroy the cursor shape device.
The device cursor shape remains unchanged.
pub fn set_shape(&self, serial: u32, shape: Shape)
pub fn set_shape(&self, serial: u32, shape: Shape)
set device cursor to the shape
Sets the device cursor to the specified shape. The compositor will change the cursor image based on the specified shape.
The cursor actually changes only if the input device focus is one of the requesting client’s surfaces. If any, the previous cursor image (surface or shape) is replaced.
The “shape” argument must be a valid enum entry, otherwise the invalid_shape protocol error is raised.
This is similar to the wl_pointer.set_cursor and zwp_tablet_tool_v2.set_cursor requests, but this request accepts a shape instead of contents in the form of a surface. Clients can mix set_cursor and set_shape requests.
The serial parameter must match the latest wl_pointer.enter or zwp_tablet_tool_v2.proximity_in serial number sent to the client. Otherwise the request will be ignored.